@@ -19,7 +19,7 @@ def options(name, option=None, value=None, opt_dict=None):
             The name of the option.  See section below.
         value : str/int/float/list
             The value of the option.  See section below.
-        dict : dict
+        opt_dict : dict
             This can be a dictionary of option:value pairs.  Option and value
             will not be needed if this dictionary item is supplied.
 
@@ -168,12 +168,45 @@ def options(name, option=None, value=None, opt_dict=None):
                 _reset_plots(i)
                 pytplot.data_quants[i].attrs['plot_options']['extras']['map'] = value
 
-            if option == 'legend_names':
+            if option == 'legend_names' or option == 'labels':
                 if isinstance(value, list):
                     pytplot.data_quants[i].attrs['plot_options']['yaxis_opt']['legend_names'] = value
                 else:
                     pytplot.data_quants[i].attrs['plot_options']['yaxis_opt']['legend_names'] = [value]
 
+            if option == 'legend_location' or option == 'labels_location':
+                pytplot.data_quants[i].attrs['plot_options']['yaxis_opt']['legend_location'] = value
+
+            if option == 'legend_size' or option == 'labels_size':
+                pytplot.data_quants[i].attrs['plot_options']['yaxis_opt']['legend_size'] = value
+
+            if option == 'legend_shadow' or option == 'labels_shadow':
+                pytplot.data_quants[i].attrs['plot_options']['yaxis_opt']['legend_shadow'] = value
+
+            if option == 'legend_title' or option == 'labels_title':
+                pytplot.data_quants[i].attrs['plot_options']['yaxis_opt']['legend_title'] = value
+
+            if option == 'legend_titlesize' or option == 'labels_titlesize':
+                pytplot.data_quants[i].attrs['plot_options']['yaxis_opt']['legend_titlesize'] = value
+
+            if option == 'legend_color' or option == 'labels_color':
+                pytplot.data_quants[i].attrs['plot_options']['yaxis_opt']['legend_color'] = value
+
+            if option == 'legend_edgecolor' or option == 'labels_edgecolor':
+                pytplot.data_quants[i].attrs['plot_options']['yaxis_opt']['legend_edgecolor'] = value
+
+            if option == 'legend_facecolor' or option == 'labels_facecolor':
+                pytplot.data_quants[i].attrs['plot_options']['yaxis_opt']['legend_facecolor'] = value
+
+            if option == 'legend_markerfirst' or option == 'labels_markerfirst':
+                pytplot.data_quants[i].attrs['plot_options']['yaxis_opt']['legend_markerfirst'] = value
+
+            if option == 'legend_markerscale' or option == 'labels_markerscale':
+                pytplot.data_quants[i].attrs['plot_options']['yaxis_opt']['legend_markerscale'] = value
+
+            if option == 'legend_frameon' or option == 'labels_frameon':
+                pytplot.data_quants[i].attrs['plot_options']['yaxis_opt']['legend_markerscale'] = value
+
             if option == 'xlog_slice':
                 if value:
                     pytplot.data_quants[i].attrs['plot_options']['slice_xaxis_opt']['xi_axis_type'] = 'log'
@@ -207,7 +240,7 @@ def options(name, option=None, value=None, opt_dict=None):
             if option == 'nodata':
                 pytplot.data_quants[i].attrs['plot_options']['line_opt']['visible'] = value
 
-            if option == 'line_style':
+            if option == 'line_style' or option == 'linestyle':
                 if value == 0 or value == 'solid_line':
                     to_be = []
                 elif value == 1 or value == 'dot':
@@ -224,12 +257,16 @@ def options(name, option=None, value=None, opt_dict=None):
                     to_be=value
 
                 pytplot.data_quants[i].attrs['plot_options']['line_opt']['line_style'] = to_be
-                pytplot.data_quants[i].attrs['plot_options']['line_opt']['line_style_name'] = value
+
+                if isinstance(value, list):
+                    pytplot.data_quants[i].attrs['plot_options']['line_opt']['line_style_name'] = value
+                else:
+                    pytplot.data_quants[i].attrs['plot_options']['line_opt']['line_style_name'] = [value]
 
                 if(value == 6 or value == 'none'):
                     pytplot.data_quants[i].attrs['plot_options']['line_opt']['visible'] = False
 
-            if option == 'char_size':
+            if option == 'char_size' or option == 'charsize':
                 pytplot.data_quants[i].attrs['plot_options']['extras']['char_size'] = value
 
             if option == 'name':
@@ -250,11 +287,68 @@ def options(name, option=None, value=None, opt_dict=None):
                     return
                 pytplot.data_quants[i].attrs['plot_options']['extras']['alpha'] = value
 
+            if option == 'marker':
+                pytplot.data_quants[i].attrs['plot_options']['line_opt']['marker'] = value
+
+            if option == 'errorevery':
+                pytplot.data_quants[i].attrs['plot_options']['line_opt']['errorevery'] = value
+
+            if option == 'capsize':
+                pytplot.data_quants[i].attrs['plot_options']['line_opt']['capsize'] = value
+
+            if option == 'ecolor':
+                pytplot.data_quants[i].attrs['plot_options']['line_opt']['ecolor'] = value
+
+            if option == 'elinewidth':
+                pytplot.data_quants[i].attrs['plot_options']['line_opt']['elinewidth'] = value
+                
+            if option == 'marker_size':
+                pytplot.data_quants[i].attrs['plot_options']['line_opt']['marker_size'] = value
+
+            if option == 'markevery':
+                pytplot.data_quants[i].attrs['plot_options']['line_opt']['markevery'] = value
+
+            if option == 'symbols':
+                pytplot.data_quants[i].attrs['plot_options']['line_opt']['symbols'] = value
+
+            if option == 'xtick_length':
+                pytplot.data_quants[i].attrs['plot_options']['extras']['xtick_length'] = value
+
+            if option == 'ytick_length':
+                pytplot.data_quants[i].attrs['plot_options']['extras']['ytick_length'] = value
+
+            if option == 'xtick_width':
+                pytplot.data_quants[i].attrs['plot_options']['extras']['xtick_width'] = value
+
+            if option == 'ytick_width':
+                pytplot.data_quants[i].attrs['plot_options']['extras']['ytick_width'] = value
+
+            if option == 'xtick_color':
+                pytplot.data_quants[i].attrs['plot_options']['extras']['xtickcolor'] = value
+
+            if option == 'ytick_color':
+                pytplot.data_quants[i].attrs['plot_options']['extras']['ytickcolor'] = value
+
+            if option == 'xtick_labelcolor':
+                pytplot.data_quants[i].attrs['plot_options']['extras']['xtick_labelcolor'] = value
+
+            if option == 'ytick_labelcolor':
+                pytplot.data_quants[i].attrs['plot_options']['extras']['ytick_labelcolor'] = value
+
+            if option == 'xtick_direction':
+                pytplot.data_quants[i].attrs['plot_options']['extras']['xtick_direction'] = value
+
+            if option == 'ytick_direction':
+                pytplot.data_quants[i].attrs['plot_options']['extras']['ytick_direction'] = value
+
             if option == 'right_axis':
                 pytplot.data_quants[i].attrs['plot_options']['extras']['right_axis'] = value
 
             if option == 'thick':
-                pytplot.data_quants[i].attrs['plot_options']['line_opt']['line_width'] = value
+                if isinstance(value, list):
+                    pytplot.data_quants[i].attrs['plot_options']['line_opt']['line_width'] = value
+                else:
+                    pytplot.data_quants[i].attrs['plot_options']['line_opt']['line_width'] = [value]
 
             if option == 'yrange' or option == 'y_range':
                 pytplot.data_quants[i].attrs['plot_options']['yaxis_opt']['y_range'] = [value[0], value[1]]
@@ -286,6 +380,12 @@ def options(name, option=None, value=None, opt_dict=None):
             if option == 'zsubtitle':
                 pytplot.data_quants[i].attrs['plot_options']['zaxis_opt']['axis_subtitle'] = value
 
+            if option == 'ytitle_color':
+                pytplot.data_quants[i].attrs['plot_options']['yaxis_opt']['axis_color'] = value
+
+            if option == 'ztitle_color':
+                pytplot.data_quants[i].attrs['plot_options']['zaxis_opt']['axis_color'] = value
+
             if option == 'ybar':
                 pytplot.data_quants[i].attrs['plot_options']['extras']['ybar'] = value
 
